/*
 * Purple - Internet Messaging Library
 * Copyright (C) Pidgin Developers <devel@pidgin.im>
 *
 * Purple is the legal property of its developers, whose names are too numerous
 * to list here. Please refer to the COPYRIGHT file distributed with this
 * source distribution.
 *
 * This library is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by the Free
 * Software Foundation; either version 2 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for
 * more details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this library; if not, see <https://www.gnu.org/licenses/>.
 */

#if !defined(PURPLE_GLOBAL_HEADER_INSIDE) && !defined(PURPLE_COMPILATION)
# error "only <purple.h> may be included directly"
#endif

#ifndef PURPLE_COMMANDS_H
#define PURPLE_COMMANDS_H

#include <glib.h>
#include <glib-object.h>

#include "purplecommand.h"
#include "purpleversion.h"

G_BEGIN_DECLS

/**
 * purple_action_command_new:
 *
 * Create a new `action` command.
 *
 * An action command will create a message out of the given parameters and set
 * [property@Message:action] to %TRUE on the message before sending it.
 *
 * Returns: (transfer full): The new instance.
 *
 * Since: 3.0
 */
PURPLE_AVAILABLE_IN_3_0
PurpleCommand *purple_action_command_new(void);

/**
 * purple_say_command_new:
 *
 * Creates a new `say` command.
 *
 * The `say` command creates a message from the parameters and writes it to the
 * conversation. This is typically used in combination with the `alias` command
 * to create shortcut commands.
 *
 * The `say` command has no tags meaning it will be available in all
 * conversations.
 *
 * Returns: (transfer full): The new instance.
 *
 * Since: 3.0
 */
PURPLE_AVAILABLE_IN_3_0
PurpleCommand *purple_say_command_new(void);

G_END_DECLS

#endif /* PURPLE_COMMANDS_H */
